import io

from simple_blast.blasting import (
    TabularBlastnSearch,
    default_out_columns
)
from simple_blast.multiformat import MultiformatBlastnSearch
from .simple_blast_test import (
    SimpleBlastTestCase,
)

class TestMultiformatBlastnSearch(SimpleBlastTestCase):
    def test_construction(self):
        subject_str = "subject.fasta"
        query_str = "query.fasta"
        res = MultiformatBlastnSearch(subject_str, query_str)
        self.assertEqual(res.out_format, 11)

    def test_basic_search(self):
        try:
            import pyblast4_archive
        except ImportError:
            self.skipTest("pyblast4_archive not installed.")
        search = MultiformatBlastnSearch(
            self.data_dir / "seqs_0.fasta",
            self.data_dir / "queries.fasta"
        )
        # This just tests that we get a valid Blast4-Archive as output for now.
        pyblast4_archive.Blast4Archive.from_file(
            io.BytesIO(search.get_output()),
            "asn_text"
        )

    def test_to(self):
        search = MultiformatBlastnSearch(
            self.data_dir / "seqs_0.fasta",
            self.data_dir / "queries.fasta"
        )
        res = search.to(6)
        TabularBlastnSearch.parse_hits(io.BytesIO(res), default_out_columns)

    def test_to_search(self):
        subject = self.data_dir / "seqs_0.fasta",
        query = self.data_dir / "queries.fasta"
        search = MultiformatBlastnSearch(subject, query)
        res = search.to_search(6)
        self.assertIsInstance(res, TabularBlastnSearch)
        search2 = TabularBlastnSearch(subject, query)
        self.assertDataFramesEqual(res.hits, search2.hits)
    
